(* pselcss.ml     CSS functions for Psellos apps
 *
 * Copyright (c) 2022 Psellos   http://psellos.com
 *
 * Licensed under the MIT license:
 *     http://opensource.org/licenses/MIT
 *)
open Js_of_ocaml

let fround f =
    floor (f +. 0.5)

let round f =
    truncate (f +. 0.5)

(* A broken-down color is exposed as (r, g, b, a) with all four values
 * in [0.0, 1.0].
 *)
type bdcolor = float * float * float * float

(* Short name for JSOO color, a private subtype of Js.js_string Js.t.
 *)
type color = CSS.Color.js_t


let byte f =
    int_of_float (255.0 *. f +. 0.5)


(* Note: we assume that browsers don't deal in fractional pixels.
 *)

let length_px fpx =
    (* Convert a number of pixels (as a floating value) to a CSS
     * length value.
     *)
    Js.string (string_of_int (round fpx) ^ "px")

let px_length lval =
    (* Convert a CSS length value to a number of pixels (as a floating
     * value).
     *)
    let lvalstr = Js.to_string lval in
    let slen = String.length lvalstr in
    let s' =
        if slen >= 2 && String.sub lvalstr (slen - 2) 2 = "px" then
            String.sub lvalstr 0 (slen - 2)
        else
            lvalstr (* Not going to work probably *)
    in
    float_of_string s'


let url_string string =
    (* Convert a string to a CSS url.
     *)
    Js.string ("url(" ^ string ^ ")")


let color_bdcolor (r, g, b, a) =
    (* Convert a broken-down color to a JSOO color.
     *)
    CSS.Color.(js (RGBA (byte r, byte g, byte b, a)))
