(* s24look.mli     Visual look of Slide24
 *
 * Copyright (c) 2022 Psellos   http://psellos.com
 *
 * Licensed under the MIT license:
 *     http://opensource.org/licenses/MIT
 *)
open Js_of_ocaml

type rect = float * float * float * float      (* x, y, w, h *)
type point = float * float                     (* x, y *)
type size = float * float                      (* w, h *)
type bdcolor = float * float * float * float

val bdwhite : bdcolor
val bdred : bdcolor

val clear : Pselcss.color
val white : Pselcss.color
val red : Pselcss.color
val dkwhite : Pselcss.color
val dkred : Pselcss.color

val shuffle_size : float * float
    (** Size of the buttons at the bottom of the screen.
     *)

type font_look = string * string * string
    (** The look of a font: (style, weight, family). The style and
     *  weight can be "" to indicate the normal value.
     *
     *  Some good styles are: normal, italic, oblique
     *  Some good weights are: normal, bold
     *  Some generic families are: serif, sans-serif, monospace
     *)

val font_spec : font_look -> float -> Js.js_string Js.t
    (** font_spec font_look font_size
     *
     *  Return a CSS specification for the given font at the given size
     *  (pixel units).
     *)

val font_size : font_look -> string -> float -> float -> float
    (** font_size font_look teststr width initial
     * 
     *  Calculate a good font size for the given font look so that the
     *  given test string occupies the given width. Initial is a size to
     *  start with, in units of whole pixels. Assume that the final size
     *  isn't too different, no more than (say) 10 pixels larger or
     *  smaller
     *)
